// -*- C++ -*-
/*!
 * @file  SetTargetAngle.cpp * @brief target data setting component * $Date$ 
 *
 * $Id$ 
 */
#include "SetTargetAngle.h"

// Module specification
// <rtc-template block="module_spec">
static const char* settargetangle_spec[] =
  {
    "implementation_id", "SetTargetAngle",
    "type_name",         "SetTargetAngle",
    "description",       "target data setting component",
    "version",           "1.0",
    "vendor",            "Junichiro Ooga, TOSHIBA",
    "category",          "RobotPlanner",
    "activity_type",     "PERIODIC",
    "kind",              "DataFowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    ""
  };
// </rtc-template>

SetTargetAngle::SetTargetAngle(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_TargetAngleOut("TargetAngle", m_TargetAngle)

    // </rtc-template>
{
}

SetTargetAngle::~SetTargetAngle()
{
}


RTC::ReturnCode_t SetTargetAngle::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers

  // Set OutPort buffer
  addOutPort("TargetAngle", m_TargetAngleOut);

  // Set service provider to Ports

  // Set service consumers to Ports

  // Set CORBA Service Ports

  // </rtc-template>

  // <rtc-template block="bind_config">
  // Bind variables and configuration variable

  // </rtc-template>
  
  for(int i=0; i<JOINTNUM-1; i++){
    angle[i] = 0.0;
  }
  angle[JOINTNUM-1] = 0.05;
  
  return RTC::RTC_OK;
}


/*
RTC::ReturnCode_t SetTargetAngle::onFinalize()
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t SetTargetAngle::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t SetTargetAngle::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

RTC::ReturnCode_t SetTargetAngle::onActivated(RTC::UniqueId ec_id)
{
  m_TargetAngle.data.length(JOINTNUM);
  for(int i=0; i<JOINTNUM; i++){
    m_TargetAngle.data[i] = angle[i];
  }
  m_TargetAngleOut.write();  
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t SetTargetAngle::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

RTC::ReturnCode_t SetTargetAngle::onExecute(RTC::UniqueId ec_id)
{
  int i;

  std::cout << "Input Target Joint Angle [deg]" << std::endl;
  for(i=0; i<JOINTNUM-1; i++){
    std::cout << "No." << i+1 << " = ";
    std::cin >> angle[i];
  }
  std::cout << "No." << JOINTNUM << " [m]= ";  // for hand
  std::cin >> angle[JOINTNUM-1];
    
  m_TargetAngle.data.length(JOINTNUM);
  std::cout << "Target Joint Angle=[";
  for(i=0; i<JOINTNUM-1; i++){
    m_TargetAngle.data[i] = angle[i]*DEG2RAD;
    std::cout << angle[i] << ", ";
  }
  m_TargetAngle.data[JOINTNUM-1] = angle[JOINTNUM-1];   // for hand
  std::cout << angle[JOINTNUM-1] << "]" << std::endl;

  m_TargetAngleOut.write();
  
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t SetTargetAngle::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t SetTargetAngle::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t SetTargetAngle::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t SetTargetAngle::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t SetTargetAngle::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


extern "C"
{
 
  void SetTargetAngleInit(RTC::Manager* manager)
  {
    coil::Properties profile(settargetangle_spec);
    manager->registerFactory(profile,
                             RTC::Create<SetTargetAngle>,
                             RTC::Delete<SetTargetAngle>);
  }
  
};



